@@ -75,6 +75,34 @@ class ChatEmoticonType(Enum):
     UNKNOWN__ = "UNKNOWN__"
 
 
+class Emoticon(Enum):
+    M1001 = "1001"
+    M1002 = "1002"
+    M1003 = "1003"
+    M1004 = "1004"
+    M1005 = "1005"
+    M1006 = "1006"
+    M1007 = "1007"
+    M1008 = "1008"
+    M1009 = "1009"
+    M1010 = "1010"
+    M1011 = "1011"
+    M1012 = "1012"
+    M1013 = "1013"
+    M1014 = "1014"
+    M1015 = "1015"
+    M1016 = "1016"
+    M1017 = "1017"
+    M1018 = "1018"
+    M1019 = "1019"
+    M1020 = "1020"
+    M1021 = "1021"
+    M1022 = "1022"
+    M1023 = "1023"
+    M1024 = "1024"
+    UNKNOWN__ = "UNKNOWN__"
+
+
 class ClientType(Enum):
     WEB = "WEB"
     APP = "APP"
@@ -109,3 +137,21 @@ class EmailAndPhoneVerificationTypeV2(Enum):
     RESEND = "RESEND"
     UPDATE = "UPDATE"
     UNKNOWN__ = "UNKNOWN__"
+
+
+class ChatType(Enum):
+    UNDEFINED = "UNDEFINED"
+    EMOTICON = "EMOTICON"
+    TEXT = "TEXT"
+    IMAGE = "IMAGE"
+    VOICE = "VOICE"
+    MP3 = "MP3"
+    SHORT_VIDEO = "SHORT_VIDEO"
+    CALL_LOG = "CALL_LOG"
+    SOS = "SOS"
+    LEAVE_SAFE_ZONE = "LEAVE_SAFE_ZONE"
+    ARRIVE_SAFE_ZONE = "ARRIVE_SAFE_ZONE"
+    LOW_POWER = "LOW_POWER"
+    POWER_ON = "POWER_ON"
+    POWER_OFF = "POWER_OFF"
+    UNKNOWN__ = "UNKNOWN__"
